Jenesis is a command line tool for rapid contract and service development for the Fetch.ai blockchain ecosystem and other CosmWasm-enabled blockchains.

# Installation

Install jenesis for Python 3.8 or newer via PyPI:

```
pip install jenesis
```

# Getting started

## Create a new project

```
jenesis new my_project
```

## Initialize jenesis in an existing project directory

```
jenesis init
```

## Compile contracts


```
jenesis compile
```
